RF Antenna Parameters
=====================
.. automodule:: lsl.misc.rfutil
   :members:

Simulated Stand Response
========================
.. automodule:: lsl.sim.nec_util
   :members:

Geodesy
=======
.. versionadded:: 0.3

.. automodule:: lsl.misc.geodesy
   :members: 

Ionospheric and Geomagnetic Field Models
========================================
.. versionadded:: 1.1.0

.. automodule:: lsl.misc.ionosphere
   :members:

Autostereograms
===============
.. versionadded:: 0.5.3

.. automodule:: lsl.misc.autostereogram
   :members:

Conversion Helper Functions for argparse
========================================
.. versionadded:: 1.2.4

.. automodule:: lsl.misc.parser
   :members:
